[Pkg-owncloud-commits] [owncloud-client] 66/470: Chunking: change the default chunk size to 10MB

Sandro Knauß hefee-guest at moszumanska.debian.org
Thu May 12 16:24:45 UTC 2016


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit b685f6b6b6dff2164fb9b4bfab1eef4b74938670
Author: Olivier Goffart <ogoffart at woboq.com>
Date:   Wed Feb 24 16:02:17 2016 +0100

    Chunking: change the default chunk size to 10MB
    
    As discussed with Klaas, this seems to be a better compromise.
    10MB * 3 prarralel jobs = 30MB in memory, and to retry in case of
    disconnection. Which is still reasonable.  And might make the upload
    almost twice as fast on fast network where the amount of chunk is the
    bottleneck (because of more server processing)
    
    Relates to issue #4354
---
 src/libsync/configfile.cpp | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/src/libsync/configfile.cpp b/src/libsync/configfile.cpp
index 824c2bd..32d2475 100644
--- a/src/libsync/configfile.cpp
+++ b/src/libsync/configfile.cpp
@@ -125,7 +125,7 @@ int ConfigFile::timeout() const
 quint64 ConfigFile::chunkSize() const
 {
     QSettings settings(configFile(), QSettings::IniFormat);
-    return settings.value(QLatin1String(chunkSizeC), 5*1024*1024).toLongLong(); // default to 5 MiB
+    return settings.value(QLatin1String(chunkSizeC), 10*1000*1000).toLongLong(); // default to 10 MB
 }
 
 QString ConfigFile::transmissionChecksum() const

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list